@@ -74,8 +74,16 @@ func GetAccessTokenForCLISession(ctx context.Context, id string) (string, error)
 const flyv1Scheme = "FlyV1"
 
 func AuthorizationHeader(token string) string {
+	token = strings.TrimSpace(token)
+
 	if scheme, _, ok := strings.Cut(token, " "); ok && scheme == flyv1Scheme {
 		return token
 	}
+
+	// macaroon without scheme
+	if strings.HasPrefix(token, "fm1r_") {
+		return strings.Join([]string{flyv1Scheme, token}, " ")
+	}
+
 	return fmt.Sprintf("Bearer %s", token)
 }
