@@ -35,18 +35,13 @@ func (c *Client) GetAppLogs(ctx context.Context, appName, token, region, instanc
 		return
 	}
 
-	req.Header.Set("Authorization", AuthorizationHeader(c.accessToken))
-	if c.trace != "" {
-		req.Header.Set("Fly-Force-Trace", c.trace)
-	}
-
 	var result getLogsResponse
 
 	var res *http.Response
 	if res, err = c.httpClient.Do(req); err != nil {
 		return
 	}
-	defer res.Body.Close()
+	defer res.Body.Close() //skipcq: GO-S2307
 
 	if res.StatusCode != 200 {
 		err = ErrorFromResp(res)
