@@ -715,7 +715,7 @@ type CreateAppInput struct {
 	PreferredRegion *string `json:"preferredRegion,omitempty"`
 	Network         *string `json:"network,omitempty"`
 	AppRoleID       string  `json:"appRoleId,omitempty"`
-	Machines        bool    `json:"machines,omitempty"`
+	Machines        bool    `json:"machines"`
 }
 
 type LogEntry struct {
