@@ -167,6 +167,7 @@ func TestToDefinition(t *testing.T) {
 		"primary_region":  "sea",
 		"kill_signal":     "SIGTERM",
 		"kill_timeout":    "3s",
+		"swap_size_mb":    int64(512),
 		"console_command": "/bin/bash",
 
 		"build": map[string]any{
@@ -256,6 +257,27 @@ func TestToDefinition(t *testing.T) {
 				"url_prefix": "/static-assets",
 			},
 		},
+		"files": []map[string]any{
+			{
+				"guest_path":  "/path/to/hello.txt",
+				"raw_value":   "aGVsbG8gd29ybGQK",
+				"local_path":  "",
+				"secret_name": "",
+			},
+			{
+				"guest_path":  "/path/to/secret.txt",
+				"raw_value":   "",
+				"secret_name": "SUPER_SECRET",
+				"local_path":  "",
+			},
+			{
+				"guest_path":  "/path/to/config.yaml",
+				"raw_value":   "",
+				"secret_name": "",
+				"local_path":  "/local/path/config.yaml",
+				"processes":   []any{"web"},
+			},
+		},
 		"mounts": []map[string]any{{
 			"source":      "data",
 			"destination": "/data",
