@@ -28,7 +28,7 @@ func TestToMachineConfig(t *testing.T) {
 		Metadata: map[string]string{
 			"fly_platform_version": "v2",
 			"fly_process_group":    "app",
-			"fly_flyctl_version":   buildinfo.Version().String(),
+			"fly_flyctl_version":   buildinfo.ParsedVersion().String(),
 		},
 		Metrics: &api.MachineMetrics{Port: 9999, Path: "/metrics"},
 		Statics: []*api.Static{{GuestPath: "/guest/path", UrlPrefix: "/url/prefix"}},
@@ -47,6 +47,9 @@ func TestToMachineConfig(t *testing.T) {
 			Timeout: api.MustParseDuration("10s"),
 			Signal:  api.Pointer("SIGTERM"),
 		},
+		Init: api.MachineInit{
+			SwapSizeMB: api.Pointer(512),
+		},
 	}
 
 	got, err := cfg.ToMachineConfig("", nil)
@@ -145,12 +148,15 @@ func TestToReleaseMachineConfig(t *testing.T) {
 	require.NoError(t, err)
 
 	want := &api.MachineConfig{
-		Init: api.MachineInit{Cmd: []string{"migrate-db"}},
-		Env:  map[string]string{"FOO": "BAR", "PRIMARY_REGION": "mia", "RELEASE_COMMAND": "1", "FLY_PROCESS_GROUP": "fly_app_release_command"},
+		Init: api.MachineInit{
+			Cmd:        []string{"migrate-db"},
+			SwapSizeMB: api.Pointer(512),
+		},
+		Env: map[string]string{"FOO": "BAR", "PRIMARY_REGION": "mia", "RELEASE_COMMAND": "1", "FLY_PROCESS_GROUP": "fly_app_release_command"},
 		Metadata: map[string]string{
 			"fly_platform_version": "v2",
 			"fly_process_group":    "fly_app_release_command",
-			"fly_flyctl_version":   buildinfo.Version().String(),
+			"fly_flyctl_version":   buildinfo.ParsedVersion().String(),
 		},
 		AutoDestroy: true,
 		Restart:     api.MachineRestart{Policy: api.MachineRestartPolicyNo},
@@ -166,6 +172,37 @@ func TestToReleaseMachineConfig(t *testing.T) {
 	assert.Equal(t, want, got)
 }
 
+func TestToConsoleMachineConfig(t *testing.T) {
+	cfg, err := LoadConfig("./testdata/tomachine.toml")
+	require.NoError(t, err)
+
+	want := &api.MachineConfig{
+		Init: api.MachineInit{
+			Exec:       []string{"/bin/sleep", "inf"},
+			SwapSizeMB: api.Pointer(512),
+		},
+		Env: map[string]string{
+			"FOO":               "BAR",
+			"PRIMARY_REGION":    "mia",
+			"FLY_PROCESS_GROUP": "fly_app_console",
+		},
+		Metadata: map[string]string{
+			"fly_platform_version": "v2",
+			"fly_process_group":    "fly_app_console",
+			"fly_flyctl_version":   buildinfo.ParsedVersion().String(),
+		},
+		AutoDestroy: true,
+		Restart: api.MachineRestart{
+			Policy: api.MachineRestartPolicyNo,
+		},
+		DNS: &api.DNSConfig{SkipRegistration: true},
+	}
+
+	got, err := cfg.ToConsoleMachineConfig()
+	assert.NoError(t, err)
+	assert.Equal(t, want, got)
+}
+
 func TestToMachineConfig_multiProcessGroups(t *testing.T) {
 	cfg, err := LoadConfig("./testdata/tomachine-processgroups.toml")
 	require.NoError(t, err)
@@ -254,7 +291,7 @@ func TestToMachineConfig_defaultV2flytoml(t *testing.T) {
 		Metadata: map[string]string{
 			"fly_platform_version": "v2",
 			"fly_process_group":    "app",
-			"fly_flyctl_version":   buildinfo.Version().String(),
+			"fly_flyctl_version":   buildinfo.ParsedVersion().String(),
 		},
 		Checks: map[string]api.MachineCheck{
 			"alive": {
