@@ -415,6 +415,7 @@ func TestLoadTOMLAppConfigReferenceFormat(t *testing.T) {
 		AppName:          "foo",
 		KillSignal:       api.Pointer("SIGTERM"),
 		KillTimeout:      api.MustParseDuration("3s"),
+		SwapSizeMB:       api.Pointer(512),
 		PrimaryRegion:    "sea",
 		ConsoleCommand:   "/bin/bash",
 		Experimental: &Experimental{
@@ -509,6 +510,22 @@ func TestLoadTOMLAppConfigReferenceFormat(t *testing.T) {
 			},
 		},
 
+		Files: []File{
+			{
+				GuestPath: "/path/to/hello.txt",
+				RawValue:  "aGVsbG8gd29ybGQK",
+			},
+			{
+				GuestPath:  "/path/to/secret.txt",
+				SecretName: "SUPER_SECRET",
+			},
+			{
+				GuestPath: "/path/to/config.yaml",
+				LocalPath: "/local/path/config.yaml",
+				Processes: []string{"web"},
+			},
+		},
+
 		Mounts: []Mount{{
 			Source:      "data",
 			Destination: "/data",
