@@ -12,7 +12,6 @@ import (
 	"strconv"
 	"time"
 
-	"github.com/blang/semver"
 	"github.com/logrusorgru/aurora"
 	"github.com/spf13/cobra"
 	"github.com/superfly/flyctl/api"
@@ -286,6 +285,17 @@ func startQueryingForNewRelease(ctx context.Context) (context.Context, error) {
 
 			cache.SetLatestRelease(channel, r)
 
+			// Check if the current version has been yanked.
+			if cache.IsCurrentVersionInvalid() == "" {
+				currentRelErr := update.ValidateRelease(ctx, buildinfo.ParsedVersion().String())
+				if currentRelErr != nil {
+					var invalidRelErr *update.InvalidReleaseError
+					if errors.As(currentRelErr, &invalidRelErr) {
+						cache.SetCurrentVersionInvalid(invalidRelErr)
+					}
+				}
+			}
+
 			logger.Debugf("querying for release resulted to %v", r.Version)
 		case errors.Is(err, context.Canceled), errors.Is(err, context.DeadlineExceeded):
 			break
@@ -345,26 +355,35 @@ func promptAndAutoUpdate(ctx context.Context) (context.Context, error) {
 	}
 
 	var (
-		cache    = cache.FromContext(ctx)
-		logger   = logger.FromContext(ctx)
-		io       = iostreams.FromContext(ctx)
-		colorize = io.ColorScheme()
-
-		current   = buildinfo.Info().Version
-		silent    = cfg.JSONOutput
+		current   = buildinfo.ParsedVersion()
+		cache     = cache.FromContext(ctx)
+		logger    = logger.FromContext(ctx)
+		io        = iostreams.FromContext(ctx)
+		colorize  = io.ColorScheme()
 		latestRel = cache.LatestRelease()
+		silent    = cfg.JSONOutput
 	)
+
 	if latestRel == nil {
 		return ctx, nil
 	}
 
-	latest, err := semver.ParseTolerant(latestRel.Version)
+	versionInvalidMsg := cache.IsCurrentVersionInvalid()
+	if versionInvalidMsg != "" && !silent {
+		fmt.Fprintf(io.ErrOut, "The current version of flyctl is invalid: %s", versionInvalidMsg)
+	}
+
+	latest, err := buildinfo.ParseVersion(latestRel.Version)
 	if err != nil {
 		logger.Warnf("error parsing version number '%s': %s", latestRel.Version, err)
-
-		return ctx, nil
+		return ctx, err
 	}
-	if latest.LTE(current) {
+
+	if !latest.Newer() {
+		if versionInvalidMsg != "" && !silent {
+			// Continuing from versionInvalidMsg above
+			fmt.Fprintln(io.ErrOut, "but there is not a newer version available. Proceed with caution!")
+		}
 		return ctx, nil
 	}
 
@@ -373,7 +392,7 @@ func promptAndAutoUpdate(ctx context.Context) (context.Context, error) {
 	// The env.IsCI check is technically redundant (it should be done in update.Check), but
 	// it's nice to be extra cautious.
 	if cfg.AutoUpdate && !env.IsCI() {
-		if severelyOutOfDate(current, latest) {
+		if versionInvalidMsg != "" || current.SeverelyOutdated(latest) {
 			if !silent {
 				fmt.Fprintln(io.ErrOut, colorize.Green(fmt.Sprintf("Automatically updating %s -> %s.", current, latestRel.Version)))
 			}
@@ -396,30 +415,20 @@ func promptAndAutoUpdate(ctx context.Context) (context.Context, error) {
 			}
 		}
 	}
-	if promptForUpdate && !silent {
-		fmt.Fprintln(io.ErrOut, colorize.Yellow(fmt.Sprintf("Update available %s -> %s.", current, latestRel.Version)))
-		fmt.Fprintln(io.ErrOut, colorize.Yellow(fmt.Sprintf("Run \"%s\" to upgrade.", colorize.Bold(buildinfo.Name()+" version upgrade"))))
+	if !silent {
+		if !cfg.AutoUpdate && versionInvalidMsg != "" {
+			// Continuing from versionInvalidMsg above
+			fmt.Fprintln(io.ErrOut, "Proceed with caution!")
+		}
+		if promptForUpdate {
+			fmt.Fprintln(io.ErrOut, colorize.Yellow(fmt.Sprintf("Update available %s -> %s.", current, latestRel.Version)))
+			fmt.Fprintln(io.ErrOut, colorize.Yellow(fmt.Sprintf("Run \"%s\" to upgrade.", colorize.Bold(buildinfo.Name()+" version upgrade"))))
+		}
 	}
 
 	return ctx, nil
 }
 
-// TODO: Move this into the generalized Version interface once that's merged
-// https://github.com/superfly/flyctl/pull/2484
-func severelyOutOfDate(current semver.Version, latest semver.Version) bool {
-
-	if current.Major < latest.Major {
-		return true
-	}
-	if current.Minor < latest.Minor {
-		return true
-	}
-	if current.Patch+5 < latest.Patch {
-		return true
-	}
-	return false
-}
-
 func PromptToMigrate(ctx context.Context, app *api.AppCompact) {
 	if app.PlatformVersion == "nomad" {
 		config := appconfig.ConfigFromContext(ctx)
