@@ -15,7 +15,7 @@ func New() *cobra.Command {
 from the Fly platform.
 `
 		short = "Permanently destroys an app"
-		usage = "destroy [APPNAME]"
+		usage = "destroy <APPNAME>"
 	)
 
 	destroy := command.New(usage, short, long, apps.RunDestroy,
