@@ -8,7 +8,6 @@ import (
 	"os/signal"
 	"runtime"
 	"strings"
-	"sync/atomic"
 	"syscall"
 	"time"
 
@@ -97,9 +96,8 @@ func newMigrateToV2() *cobra.Command {
 		},
 		flag.Bool{
 			Name:        "remote-fork",
-			Description: "Enables experimental cross-host volume forking",
+			Description: "PLACEHOLDER - this is the default now",
 			Hidden:      true,
-			Default:     false,
 		},
 	)
 
@@ -220,9 +218,8 @@ type v2PlatformMigrator struct {
 	newMachines          machine.MachineSet
 	recovery             recoveryState
 	usesForkedVolumes    bool
-	usesRemoteVolumeFork bool
 	createdVolumes       []*NewVolume
-	replacedVolumes      map[string]int
+	replacedVolumes      map[string][]string
 	isPostgres           bool
 	pgConsulUrl          string
 	targetImg            string
@@ -328,15 +325,14 @@ func NewV2PlatformMigrator(ctx context.Context, appName string) (V2PlatformMigra
 		oldAllocs:               allocs,
 		machineGuests:           machineGuests,
 		isPostgres:              appCompact.IsPostgresApp(),
-		replacedVolumes:         map[string]int{},
+		replacedVolumes:         map[string][]string{},
 		verbose:                 flag.GetBool(ctx, "verbose"),
 		recovery: recoveryState{
 			platformVersion: appFull.PlatformVersion,
 		},
-		backupMachines:       map[string]int{},
-		machineWaitTimeout:   flag.GetDuration(ctx, "wait-timeout"),
-		skipHealthChecks:     flag.GetBool(ctx, "skip-health-checks"),
-		usesRemoteVolumeFork: flag.GetBool(ctx, "remote-fork"),
+		backupMachines:     map[string]int{},
+		machineWaitTimeout: flag.GetDuration(ctx, "wait-timeout"),
+		skipHealthChecks:   flag.GetBool(ctx, "skip-health-checks"),
 	}
 	if migrator.isPostgres {
 		consul, err := apiClient.EnablePostgresConsul(ctx, appCompact.Name)
@@ -513,7 +509,8 @@ func (m *v2PlatformMigrator) Migrate(ctx context.Context) (err error) {
 		}
 	}()
 
-	aborted := atomic.Bool{}
+	cancelableCtx, setAborted := context.WithCancel(ctx)
+	defer setAborted()
 	// Hook into Ctrl+C so that aborting the migration
 	// leaves the app in a stable, unlocked, non-detached state
 	{
@@ -529,7 +526,7 @@ func (m *v2PlatformMigrator) Migrate(ctx context.Context) (err error) {
 			<-signalCh
 			// most terminals print ^C, this makes things easier to read.
 			fmt.Fprintf(m.io.ErrOut, "\n")
-			aborted.Store(true)
+			setAborted()
 		}()
 	}
 
@@ -558,7 +555,7 @@ func (m *v2PlatformMigrator) Migrate(ctx context.Context) (err error) {
 	if err != nil {
 		return err
 	}
-	if aborted.Load() {
+	if cancelableCtx.Err() != nil {
 		return abortedErr
 	}
 
@@ -568,7 +565,7 @@ func (m *v2PlatformMigrator) Migrate(ctx context.Context) (err error) {
 		if err != nil {
 			return err
 		}
-		if aborted.Load() {
+		if cancelableCtx.Err() != nil {
 			return abortedErr
 		}
 	}
@@ -576,12 +573,12 @@ func (m *v2PlatformMigrator) Migrate(ctx context.Context) (err error) {
 	if m.requiresDowntime() {
 		tb.Detail("Scaling down to zero VMs. This will cause temporary downtime until new VMs come up.")
 
-		err = m.scaleNomadToZero(ctx)
+		err = m.scaleNomadToZero(cancelableCtx)
 		if err != nil {
 			return err
 		}
 	}
-	if aborted.Load() {
+	if cancelableCtx.Err() != nil {
 		return abortedErr
 	}
 
@@ -591,7 +588,7 @@ func (m *v2PlatformMigrator) Migrate(ctx context.Context) (err error) {
 	if err != nil {
 		return err
 	}
-	if aborted.Load() {
+	if cancelableCtx.Err() != nil {
 		return abortedErr
 	}
 
@@ -601,7 +598,7 @@ func (m *v2PlatformMigrator) Migrate(ctx context.Context) (err error) {
 	if err != nil {
 		return err
 	}
-	if aborted.Load() {
+	if cancelableCtx.Err() != nil {
 		return abortedErr
 	}
 
@@ -611,7 +608,7 @@ func (m *v2PlatformMigrator) Migrate(ctx context.Context) (err error) {
 	if err != nil {
 		return err
 	}
-	if aborted.Load() {
+	if cancelableCtx.Err() != nil {
 		return abortedErr
 	}
 
@@ -625,7 +622,7 @@ func (m *v2PlatformMigrator) Migrate(ctx context.Context) (err error) {
 	if err != nil {
 		return err
 	}
-	if aborted.Load() {
+	if cancelableCtx.Err() != nil {
 		return abortedErr
 	}
 	m.newMachines.StartBackgroundLeaseRefresh(ctx, m.leaseTimeout, m.leaseDelayBetween)
@@ -634,16 +631,16 @@ func (m *v2PlatformMigrator) Migrate(ctx context.Context) (err error) {
 	if err != nil {
 		return err
 	}
-	if aborted.Load() {
+	if cancelableCtx.Err() != nil {
 		return abortedErr
 	}
 
 	m.newMachines.ReleaseLeases(ctx)
-	err = m.deployApp(ctx)
+	err = m.deployApp(cancelableCtx)
 	if err != nil {
 		return err
 	}
-	if aborted.Load() {
+	if cancelableCtx.Err() != nil {
 		return abortedErr
 	}
 
@@ -678,7 +675,7 @@ func (m *v2PlatformMigrator) Migrate(ctx context.Context) (err error) {
 		if err != nil {
 			return err
 		}
-		if aborted.Load() {
+		if cancelableCtx.Err() != nil {
 			return abortedErr
 		}
 	}
@@ -971,7 +968,7 @@ func (m *v2PlatformMigrator) ConfirmChanges(ctx context.Context) (bool, error) {
 	}
 	if m.usesForkedVolumes {
 		fmt.Fprintf(m.io.Out, " * Create clones of each volume in use, for the new machines\n")
-		fmt.Fprintf(m.io.Out, "   * These cloned volumes will have the suffix '%s' appended to their names\n", forkedVolSuffix)
+		fmt.Fprintf(m.io.Out, "   * These cloned volumes will have the same name but different id\n")
 		fmt.Fprintf(m.io.Out, "   * Please note that your old volumes will not be removed.\n")
 		fmt.Fprintf(m.io.Out, "     (you can do this manually, after making sure the migration was a success)\n")
 	}
