@@ -6,7 +6,7 @@ import (
 	"github.com/superfly/flyctl/helpers"
 )
 
-func configureStatic(sourceDir string) (*SourceInfo, error) {
+func configureStatic(sourceDir string, config *ScannerConfig) (*SourceInfo, error) {
 	// No index.html detected, move on
 	if !helpers.FileExists(filepath.Join(sourceDir, "index.html")) {
 		return nil, nil
