@@ -9,6 +9,7 @@ import (
 
 	"github.com/jpillora/backoff"
 	"github.com/samber/lo"
+	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
 	"github.com/superfly/flyctl/api"
 	"github.com/superfly/flyctl/test/preflight/testlib"
@@ -185,19 +186,6 @@ func TestFlyLaunchForceV1(t *testing.T) {
 	require.Contains(f, x.StdErr().String(), `--force-nomad won't work for existing app in machines platform`)
 }
 
-// V1 app forced as V2
-func TestFlyLaunchForceV2(t *testing.T) {
-	f := testlib.NewTestEnvFromEnv(t)
-
-	appName := f.CreateRandomAppName()
-	// Sadly creating a new app with --nomad doesn't set its platform to Nomad until first deploy
-	f.Fly("apps create %s -o %s --nomad", appName, f.OrgSlug())
-	f.Fly("launch --now --image nginx --name %s --reuse-app --region=%s --force-nomad", appName, f.PrimaryRegion())
-
-	x := f.FlyAllowExitFailure("launch --no-deploy --copy-config=false --reuse-app --name %s --region %s --force-machines", appName, f.PrimaryRegion())
-	require.Contains(f, x.StdErr().String(), `--force-machines won't work for existing app in nomad platform`)
-}
-
 // test --generate-name, --name and reuse imported name
 func TestFlyLaunchReuseName(t *testing.T) {
 	f := testlib.NewTestEnvFromEnv(t)
@@ -352,3 +340,18 @@ func TestFlyLaunchSigleMount(t *testing.T) {
 	vl := f.VolumeList(appName)
 	require.Equal(f, 2, len(vl))
 }
+
+func TestFlyLaunchWithBuildSecrets(t *testing.T) {
+	f := testlib.NewTestEnvFromEnv(t)
+	appName := f.CreateRandomAppName()
+
+	// secrets are mounted under /run/secrets by default.
+	// https://docs.docker.com/engine/reference/builder/#run---mounttypesecret
+	f.WriteFile("Dockerfile", `FROM nginx
+RUN --mount=type=secret,id=secret1 cat /run/secrets/secret1 > /tmp/secrets.txt
+`)
+
+	f.Fly("launch --org %s --name %s --region %s --internal-port 80 --force-machines --ha=false --now --build-secret secret1=SECRET1 --remote-only", f.OrgSlug(), appName, f.PrimaryRegion())
+	ssh := f.Fly("ssh console -C 'cat /tmp/secrets.txt'")
+	assert.Equal(f, "SECRET1", ssh.StdOut().String())
+}
